==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor.md <==
# AwsIoTThingTemperatureVibrationSensor


```text
aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor
```

```text
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')
```



| Illustration | AwsIoTThingTemperatureVibrationSensor | AwsIoTThingTemperatureVibrationSensorCard | AwsIoTThingTemperatureVibrationSensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor.png) | ![illustration for AwsIoTThingTemperatureVibrationSensor](../../../aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor.Local.png) | ![illustration for AwsIoTThingTemperatureVibrationSensorCard](../../../aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensorCard.Local.png) | ![illustration for AwsIoTThingTemperatureVibrationSensorGroup](../../../aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensorGroup.Local.png) |




## AwsIoTThingTemperatureVibrationSensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensor
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensor('AwsIoTThingTemperatureVibrationSensor', 'Aws Io T Thing Temperature Vibration Sensor', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensor
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensor('AwsIoTThingTemperatureVibrationSensor', 'Aws Io T Thing Temperature Vibration Sensor', 'an optional tech label')
@enduml
```

## AwsIoTThingTemperatureVibrationSensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensorCard
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensorCard('AwsIoTThingTemperatureVibrationSensorCard', 'Aws Io T Thing Temperature Vibration Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensorCard
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensorCard('AwsIoTThingTemperatureVibrationSensorCard', 'Aws Io T Thing Temperature Vibration Sensor Card', 'an optional description')
@enduml
```

## AwsIoTThingTemperatureVibrationSensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensorGroup
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensorGroup('AwsIoTThingTemperatureVibrationSensorGroup', 'Aws Io T Thing Temperature Vibration Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensorGroup
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensorGroup('AwsIoTThingTemperatureVibrationSensorGroup', 'Aws Io T Thing Temperature Vibration Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor.md <==
# AwsIoTThingTemperatureVibrationSensor


```text
aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor
```

```text
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')
```



| Illustration | AwsIoTThingTemperatureVibrationSensor | AwsIoTThingTemperatureVibrationSensorCard | AwsIoTThingTemperatureVibrationSensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor.png) | ![illustration for AwsIoTThingTemperatureVibrationSensor](../../../aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor.Local.png) | ![illustration for AwsIoTThingTemperatureVibrationSensorCard](../../../aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensorCard.Local.png) | ![illustration for AwsIoTThingTemperatureVibrationSensorGroup](../../../aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensorGroup.Local.png) |




## AwsIoTThingTemperatureVibrationSensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensor
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensor('AwsIoTThingTemperatureVibrationSensor', 'Aws Io T Thing Temperature Vibration Sensor', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensor
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensor('AwsIoTThingTemperatureVibrationSensor', 'Aws Io T Thing Temperature Vibration Sensor', 'an optional tech label', 'an optional description')
@enduml
```

## AwsIoTThingTemperatureVibrationSensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensorCard
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensorCard('AwsIoTThingTemperatureVibrationSensorCard', 'Aws Io T Thing Temperature Vibration Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensorCard
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensorCard('AwsIoTThingTemperatureVibrationSensorCard', 'Aws Io T Thing Temperature Vibration Sensor Card', 'an optional description')
@enduml
```

## AwsIoTThingTemperatureVibrationSensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensorGroup
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensorGroup('AwsIoTThingTemperatureVibrationSensorGroup', 'Aws Io T Thing Temperature Vibration Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTThingTemperatureVibrationSensorGroup
include('aws-q2-2022/Resource/LoT/AwsIoTThingTemperatureVibrationSensor')

' renders the element
AwsIoTThingTemperatureVibrationSensorGroup('AwsIoTThingTemperatureVibrationSensorGroup', 'Aws Io T Thing Temperature Vibration Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
